pub fn get_file_priority(path: &str, rules: &[PriorityRule]) -> i32Expand description
Determine final priority of a file by scanning the priority list in descending order of score.
pub fn get_file_priority(path: &str, rules: &[PriorityRule]) -> i32Determine final priority of a file by scanning the priority list in descending order of score.